//                                                                                
//    Copyright (c) 2004/2005 Thomas Fuchs / The Rockin'-B, www.rockin-b.de       
//                                                                                
//    Permission is granted to anyone to use this software for any purpose        
//    and to redistribute it freely, subject to the following restrictions:       
//                                                                                
//    1.  The origin of this software must not be misrepresented. You must not    
//        claim that you wrote the original software. If you use this software    
//        in a product, an acknowledgment in the product documentation would be   
//        appreciated but is not required.                                        
//                                                                                
//    2.  ANY COMMERCIAL USE IS PROHIBITED. This includes that you must not use   
//        this software in the production of a commercial product. Only an explicit
//        permission by the author can allow you to do that.                      
//                                                                                
//    3.  Any modification applied to the software must be marked as such clearly.
//                                                                                
//    4.  This license may not be removed or altered from any distribution.       
//                                                                                
//                                                                                
//    			    NO WARRANTY                                                 
//                                                                                
//    THERE IS NO WARRANTY FOR THE PROGRAM.                                       
//    THE PROGRAM IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND,               
//    EITHER EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO,                 
//    THE IMPLIED WARRANTIES OF FITNESS FOR A PARTICULAR PURPOSE.                 
//    THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH YOU.
//    SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL NECESSARY    
//    SERVICING, REPAIR OR CORRECTION.                                            
//                                                                                
//    IN NO EVENT WILL THE COPYRIGHT HOLDER BE LIABLE TO YOU FOR DAMAGES,         
//    INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING 
//    OUT OF THE USE OR INABILITY TO USE THE PROGRAM (INCLUDING BUT NOT LIMITED   
//    TO LOSS OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY    
//    YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER  
//    PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE       
//    POSSIBILITY OF SUCH DAMAGES.                                                
//                                                                                

#ifndef HAVE_RB_DRV_DEF_H
#define HAVE_RB_DRV_DEF_H

#include <SGL.H>
#include <RB_MAP_def.h>

// results of collision detection
typedef struct COLL {
    struct {
        unsigned char hit, typeID;
    } left, right, mid;
    // only needed for mid
    FIXED dirX, dirZ, height, angX, angZ;	
} Coll;

// camera related
typedef struct CAM {
    FIXED pos[XYZ];
    FIXED target[XYZ];
    ANGLE angZ;
} Cam;

// car movement
typedef struct DRIVE {
    FIXED heightOffset;
    FIXED pos[XYZ], pos2[XYZ];
    FIXED pos_add[XYZ], pos_add2[XYZ];
    Sint16 pos_add2_xx;
    ANGLE ang[XYZ], ang2[XYZ];
    ANGLE ang_add;
    FIXED eg_speed;
    // reduce slSin() and slCos() calls
    FIXED sineY, cosineY;
} Drive;

// car specs
typedef struct CAR {
    int width;
    struct {
        FIXED unit, max, min;
    } speed;
    struct {
        ANGLE unit;
    } ang;
    // decrease pos_add and pos_add2
    FIXED paDec, pa2Dec, aaDec;
    int downforce;
} Car;

typedef struct WINDOW {
    Uint16 left, top, right, bottom, vanishX, vanishY;
} Window;

typedef struct PLAYER {
    Cam cam;
    Drive drive;
    Car car;
    Coll coll;
    Window window;
    MapData *map;
} Player;


#endif // HAVE_RB_DRV_DEF_H

